<p align="center">
    <img src="https://socialify.git.ci/Sitoi/dailycheckin/image?description=1&font=Rokkitt&forks=1&issues=1&language=1&owner=1&pattern=Circuit%20Board&pulls=1&stargazers=1&theme=Dark"/>
    <br><strong><font size=50>每日签到集合</font></strong>
    <br>基于【腾讯云函数】/【GitHub Actions】/【Docker】的每日签到脚本
    <br>支持多账号使用
</p>

<p align="center">
    <a href="https://t.me/dailycheckin"><img src="https://img.shields.io/badge/Talk-Telegram-brightgreen.svg?style=popout-square" alt="Telegram"></a>
    <a href="https://github.com/Sitoi/dailycheckin/stargazers"><img src="https://img.shields.io/github/stars/Sitoi/dailycheckin.svg?style=popout-square" alt="GitHub stars"></a>
    <a href="https://github.com/Sitoi/dailycheckin/network/members"><img src="https://img.shields.io/github/forks/Sitoi/dailycheckin.svg?style=popout-square" alt="GitHub forks"></a>
    <a href="https://github.com/Sitoi/dailycheckin/issues"><img src="https://img.shields.io/github/issues/Sitoi/dailycheckin.svg?style=popout-square" alt="GitHub issues"></a>
    <a href="https://hub.docker.com/repository/docker/sitoi/dailycheckin"><img src="https://img.shields.io/docker/pulls/sitoi/dailycheckin?style=popout-square" alt="Docker Pulls"></a>
    <a href="https://pypi.org/project/dailycheckin/"><img src="https://img.shields.io/pypi/dm/dailycheckin?label=pypi&style=flat-square" alt="Pypi Download"></a>
    <a href="https://sitoi.github.io/dailycheckin"><img src="https://visitor-badge.glitch.me/badge?page_id=Sitoi-dailycheckin" alt="visitor"></a>
</p>

## 特别声明

- 本仓库发布的脚本及其中涉及的任何解锁和解密分析脚本，仅用于测试和学习研究，禁止用于商业用途，不能保证其合法性，准确性，完整性和有效性，请根据情况自行判断。

- 本项目内所有资源文件，禁止任何公众号、自媒体进行任何形式的转载、发布。

- 本人对任何脚本问题概不负责，包括但不限于由任何脚本错误导致的任何损失或损害。

- 间接使用脚本的任何用户，包括但不限于建立VPS或在某些行为违反国家/地区法律或相关法规的情况下进行传播, 本人对于由此引起的任何隐私泄漏或其他后果概不负责。

- 请勿将本仓库的任何内容用于商业或非法目的，否则后果自负。

- 如果任何单位或个人认为该项目的脚本可能涉嫌侵犯其权利，则应及时通知并提供身份证明，所有权证明，我们将在收到认证文件后删除相关脚本。

- 任何以任何方式查看此项目的人或直接或间接使用该项目的任何脚本的使用者都应仔细阅读此声明。本人保留随时更改或补充此免责声明的权利。一旦使用并复制了任何相关脚本或Script项目的规则，则视为您已接受此免责声明。

**您必须在下载后的24小时内从计算机或手机中完全删除以上内容**

> ***您使用或者复制了本仓库且本人制作的任何脚本，则视为 `已接受` 此声明，请仔细阅读***

## 详细文档

- 国内地址: [https://sitoi.gitee.io/dailycheckin/](https://sitoi.gitee.io/dailycheckin/)

## 签到列表

🟢: 正常运行 🔴: 脚本暂不可用 🔵: 可以执行(需更新) 🟡: 待测试 🟤: 看脸

|类别|名称|备注|终端|Cookie 时长|状态|
|:---:|:---:|:---|:---:|:---:|:---:|
|签到|[爱奇艺](https://www.iqiyi.com/)|签7天奖1天，14天奖2天，28天奖7天；日常任务4成长值；随机成长值；三次抽奖|WEB|待测试|🟢️|
|签到|[全民K歌](https://kg.qq.com/index-pc.html)|每日签到获取鲜花 每日大约 150 鲜花左右|WEB|待测试|🟢️|
|签到|[腾讯视频](https://v.qq.com/)|每日两次腾讯视频签到获取成长值|WEB|待测试|🟢️|
|签到|[有道云笔记](https://note.youdao.com/web/)|每日签到获取存储空间|WEB|待测试|🟢️|
|签到|[网易云音乐](https://music.163.com/)|每日自动登录签到 + 刷歌 310 首|WEB|永久|🟢️|
|签到|[一加手机社区官方论坛](https://www.oneplusbbs.com/)|论坛每日签到 + 10 次抽奖任务|WEB|待测试|🟢️|
|签到|[百度贴吧](https://tieba.baidu.com/index.html)|贴吧每日签到|WEB|待测试|🟢️|
|签到|[Bilibili](https://www.bilibili.com)|直播签到，漫画签到，每日经验任务，自动投币，银瓜子换硬币等功能|WEB|待测试|🟢️|
|签到|[V2EX](https://www.v2ex.com/)|铜币奖励|WEB|待测试|🟢️|
|签到|[咔叽网单](https://www.2nzz.com/)|论坛金币|WEB|待测试|🟢️|
|签到|[什么值得买](https://www.smzdm.com)|每日签到|WEB|待测试|🟢️|
|签到|[AcFun](https://www.acfun.cn/)|每日签到香蕉|WEB|永久|🟢️|
|签到|[天翼云盘](https://cloud.189.cn/)|每日签到 +2次抽奖获得空间奖励|WEB|永久|🟢️|
|签到|[吾爱破解](https://www.52pojie.cn/index.php)|2枚吾爱币|WEB|待测试|🟤|
|签到|[哔咔漫画](https://www.picacomic.com)|成长值奖励|WEB|永久|🟤|
|签到|[MEIZU 社区](https://bbs.meizu.cn)|每日签到、可配置抽奖|WEB|待测试|🟢️|
|签到|[智友邦](http://zhizhiyoo.net/)|每日签到获取金币|WEB|待测试|🟢️|
|签到|[CSDN](https://www.csdn.net/)|每日签到、抽奖|WEB|待测试|🟢️|
|签到|联通沃邮箱|每日签到，签到7天得2元话费|公众号|待测试|🟢|
|签到|王者营地|每日签到（仅限 QQ 区）|APP|待测试|🟢|
|签到|微博|每日钱包签到、打卡|APP|待测试|🟢️|
|签到|多看阅读|获取书豆，用于购买书籍|APP|待测试|🟢️|
|签到|芒果 TV|签到获取体验会员|APP|待测试|🟢️|
|签到|Fa 米家|连续签到7天总计获得6粒Fa米粒，每月15号23.59分清空Fa米粒。理论一个月最少获得24粒fa米粒。|APP|待测试|🟢️|
|其他|小米运动|每日小米运动刷步数|APP|永久|🟢️|
|其他|[百度搜索资源平台](https://ziyuan.baidu.com/site/index#/)|提交网站页面供百度收录|WEB|永久|🟢️|
|其他|每日天气预报|获取指定的多个城市天气信息|WEB|永久|🟢️|
|其他|每日一句|从词霸中获取每日一句，带英文|WEB|永久|🟢️|

## 支持的通知列表

- dingtalk（钉钉）
- 企业微信群机器人（企业微信）
- 企业微信应用消息（企业微信）
- telegram（TG）
- Bark（iOS）
- server 酱（微信）
- server 酱 TURBO（微信）
- pushplus（微信）
- Cool Push（QQ,微信,邮箱）
- qmsg 酱（QQ）

## 特别鸣谢

- [@Wenmoux](https://github.com/Wenmoux/checkbox) - 签到盒
- [@chavyleung](https://github.com/chavyleung/scripts) - Chavy Scripts

## 交流群

<table> 
<tr> 
 <td> <p align="center">微信群</p> <img width="282" height="282" src="https://cdn.jsdelivr.net/gh/Sitoi/dailycheckin/docs/img/wechat.gif" /> <p align="center">进群加微信，备注：签到</p> </td> 
 <td> <p align="center">QQ群</p> <img width="282" height="282" src="https://cdn.jsdelivr.net/gh/Sitoi/dailycheckin/docs/img/qq.gif" /> <p align="center">扫码进QQ群</p> </td> 
</tr> 
</table>

## 其他

<details>
<summary>更新日志（点击展开）</summary>

- 2021-04-28
    * 添加【联通沃邮箱】每日签到脚本 感谢水友`@什么大风大浪都见过` 提供脚本
- 2021-04-07
    * 添加【王者营地】每日签到脚本
    * 添加【CSDN】每日签到脚本
    * 添加【AcFun】每日分享任务功能
- 2021-03-30
    * 添加【微博】每日签到脚本
    * 添加【多看阅读】每日签到脚本
- 2021-03-16 添加【智友邦】每日签到脚本
- 2021-03-10 添加【爱奇艺】10s 任务
- 2021-03-09
    * 添加【pushplus】推送功能
    * 添加【配置文件】GitHub Actions 使用整个 config.json 配置文件
- 2021-03-06 添加【和彩云】签到和抽奖功能
- 2021-03-03 添加【MEIZU 社区】签到和抽奖功能
- 2021-03-02
    * 添加【企业微信群机器人】推送功能
    * 添加【企业微信应用消息】推送功能
- 2021-03-01
    * 添加【哔咔漫画】每日签到脚本
    * 添加【芒果TV】每日签到脚本
- 2021-02-23
    * 添加【WPS】每日签到脚本
    * 添加【吾爱破解】每日签到脚本
- 2021-02-21 添加【全民K歌】VIP 每日签到脚本
- 2021-02-20 添加【server酱 turbo 版】推送功能
- 2021-01-27 添加【天翼云盘】每日签到脚本
- 2021-01-22 添加【AcFun】每日签到脚本
- 2021-01-19 添加【Bark】推送功能
- 2021-01-16 添加【小米运动】刷步数功能
- 2021-01-07
    * 添加【什么值得买】每日签到脚本
    * 添加【咔叽网单】每日签到脚本
    * 添加【V2EX】每日签到脚本
- 2021-01-03 添加【联通】每日签到脚本
- 2020-12-22 添加【Cool Push】推送功能
- 2020-12-21
    * 添加【bilibili】每日签到脚本
    * 添加【百度贴吧】每日签到脚本
- 2020-12-19 添加【Fa 米家 App】每日签到脚本
- 2020-12-10 添加【一加手机社区官方论坛】每日签到脚本
- 2020-12-07
    * 添加【每日天气】预报
    * 添加【每日一句】获取
- 2020-12-06
    * 添加【网易云音乐】每日签到脚本
    * 添加【腾讯视频】每日签到脚本
    * 添加【吾爱破解】每日签到脚本
    * 添加【有道云笔记】每日签到脚本
    * 添加【爱奇艺】每日签到脚本
    * 添加【百度站点】每日提交脚本

</details> 

## 历史 Star 数

<p align="center">
    <a href="https://starchart.cc/Sitoi/dailycheckin"><img src="https://starchart.cc/Sitoi/dailycheckin.svg" alt="starchart"></a>
</p>